.. Sage documentation master file, created by sphinx-quickstart on Thu Aug 21 20:15:55 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Benvenuti al tutorial di Sage!
================================

Sage è un software di calcolo numerico e simbolico libero e open-source di supporto
nell'insegnamento e della ricerca in algebra, geometria, teoria dei numeri, crittografia,
calcolo numerico e aree correlate. Sia il modello di sviluppo di Sage, sia la tecnologia 
utilizzata in Sage stesso, si distinguono per un'enfasi particolarmente forte 
su apertura, community, cooperazione e collaborazione: vogliamo creare 
l'automobile, non reinventare la ruota. L'obiettivo complessivo di Sage è creare 
un'alternativa adeguata, libera e open-source a Maple, Mathematica, Magma e 
MATLAB.

Questo tutorial è la via migliore per familiarizzare con Sage in poche ore e può 
essere letto in HTML o PDF.


.. toctree::
   :maxdepth: 2

   introduction
   tour_algebra

Indici e tabelle
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
